@@ -7,7 +7,7 @@
 #include <stdio.h>
 #pragma string name Fibonacci numbers
 
-void fib(int n);
+int fib(int n);
 unsigned results[11];
 
 main()
@@ -20,7 +20,7 @@ main()
 	}
 }
 
-void fib(int n)
+int fib(int n)
 {
 	if (n <= 2) return 1;
 	return fib(n-1) + fib(n-2);
