@@ -3,7 +3,7 @@
  *
  *      Stefano Bodrato - 6/9/2004
  *
- *	$Id: zxinterface1.h,v 1.6 2007/07/10 08:12:50 stefano Exp $
+ *	$Id: zxinterface1.h,v 1.8 2008/02/07 11:18:03 stefano Exp $
  */
 
 
@@ -14,6 +14,9 @@
 #include <fcntl.h>
 
 
+#ifndef __ZX_CHANNELS__
+#define	__ZX_CHANNELS__
+
 struct BASE_CHAN {
 	// base channel descriptor
 	u16_t	errptr1;	/* first pointer to main ERROR-1     */
@@ -86,6 +89,8 @@ struct N_CHAN {
 	char    data[255];	/* 255 byte data buffer */
 };
 
+#endif /*__ZX_CHANNELS__*/
+
 
 // Load a sector identified by file name and record number
 extern int __LIB__ if1_load_record (int drive, char *filename, int record, struct M_CHAN buffer);
