@@ -8,7 +8,7 @@
  *
  *      Split into parts djm 3/3/99
  *
- *      $Id: declvar.c,v 1.14 2003/04/20 16:11:10 dom Exp $
+ *      $Id: declvar.c,v 1.16 2007/07/05 18:39:00 dom Exp $
  *
  *      The Declaration Routines
  *      (Oh they're so much fun!!)
@@ -198,7 +198,7 @@ char zfar )                      /* TRUE if far */
 {
     char sname[NAMESIZE];
     int size, ident, more, itag, type, size_st;
-    long addr;
+    long addr = -1;
     char    flagdef,match,ptrtofn;
     char    libdef,fastcall,callee;
     SYMBOL *myptr ;
@@ -297,7 +297,9 @@ char zfar )                      /* TRUE if far */
                 if (fastcall) currfn->flags|=fastcall;
             }
             if (storage==0) {
-				currfn=0;
+                if ( addr != -1 ) {
+                    currfn->size = addr;
+                }
 				return;
 			}
             /*
@@ -410,6 +412,7 @@ char zfar )                      /* TRUE if far */
                         myptr->flags&=(~CALLEE);
                         myptr->flags|=libdef|LIBRARY;
                     }
+                   
                                 
                 }
 
@@ -825,7 +828,7 @@ TAG_SYMBOL *GetVarID(struct varid *var,char storage)
         } else {
                 SYMBOL *ptr;
                 ptr=STARTGLB;
-                while ( ptr <= ENDGLB ) {
+                while ( ptr < ENDGLB ) {
                         if (ptr->name[0] && ptr->storage == TYPDEF && amatch(ptr->name) ) {
 /* Found a typedef match */
                                 var->sign=ptr->flags&UNSIGNED;
